spoon.objTypes

Package spoon :: Module objTypes |
[hide private]
[frames] | no frames]

# Module objTypes

source code

Variables | [hide private]
`` | LMTYPE_INIT = `0`
`` | LMTYPE_NETWORK = `1`
`` | LMTYPE_NETWORK_PROTO = `2`
`` | NMTYPE_MESSAGING = `0`

Variables Details | [hide private]

    ### LMTYPE_INIT None Value:
        0

    ### LMTYPE_NETWORK None Value:
        1

    ### LMTYPE_NETWORK_PROTO None Value:
        2

    ### NMTYPE_MESSAGING None Value:
        0